#ifndef SVN_REPOS_HH
#define SVN_REPOS_HH

#include <string>
#include <boost/utility.hpp>
#include <svn/pool.hh>

typedef struct svn_repos_t svn_repos_t;

namespace svn {

namespace fs {
class Filesystem;
}

namespace repos {

class Repository : private boost::noncopyable {
        friend class svn::fs::Filesystem;

    public:
        enum Mode {
            create,
            open
        };

        /**
         * Opens or creates a repository.
         * <p>Opening acquires a shared lock on the repository and attaches a
         * cleanup function to <tt>pool</tt> to remove the lock. If no lock
         * can be acquired, an exception is thrown. If an exclusive lock is
         * present, this blocks until it's gone.</p>
         * <p>Creating builds the necessary directory structure, creates the
         * Berkeley DB filesystem environment, and so on.
         **/
        Repository(const std::string &path, Pool &pool, Mode mode = open);

        /** Closes the repository. **/
        ~Repository();

    protected:
        svn_repos_t *me;
};

}
}

#endif
